@@ -21,19 +21,50 @@ Example:
 
 from .architecture import Index, Schema
 from .caster import Caster
+from .data_source import (
+    APIConfig,
+    APIDataSource,
+    AbstractDataSource,
+    DataSourceFactory,
+    DataSourceRegistry,
+    DataSourceType,
+    FileDataSource,
+    JsonFileDataSource,
+    JsonlFileDataSource,
+    PaginationConfig,
+    SQLConfig,
+    SQLDataSource,
+    TableFileDataSource,
+)
 from .db import ConnectionManager, ConnectionType
 from .filter.onto import ComparisonOperator, LogicalOperator
 from .onto import AggregationType
-from .util.onto import Patterns
+from .util.onto import FilePattern, Patterns, ResourcePattern, TablePattern
 
 __all__ = [
-    "Caster",
+    "AbstractDataSource",
+    "APIConfig",
+    "APIDataSource",
+    "AggregationType",
+    "ComparisonOperator",
     "ConnectionManager",
     "ConnectionType",
-    "ComparisonOperator",
-    "LogicalOperator",
+    "Caster",
+    "DataSourceFactory",
+    "DataSourceRegistry",
+    "DataSourceType",
+    "FileDataSource",
+    "FilePattern",
     "Index",
-    "Schema",
+    "JsonFileDataSource",
+    "JsonlFileDataSource",
+    "LogicalOperator",
+    "PaginationConfig",
     "Patterns",
-    "AggregationType",
+    "ResourcePattern",
+    "Schema",
+    "SQLConfig",
+    "SQLDataSource",
+    "TableFileDataSource",
+    "TablePattern",
 ]
