@@ -25,19 +25,20 @@ Example:
 
 from .arango.conn import ArangoConnection
 from .conn import Connection, ConnectionType
-from .connection import ConfigFactory, ConnectionKind, DBConnectionConfig
+from .connection import DBConfig, DBType
 from .manager import ConnectionManager
 from .neo4j.conn import Neo4jConnection
+from .postgres.conn import PostgresConnection
 from .tigergraph.conn import TigerGraphConnection
 
 __all__ = [
     "Connection",
     "ConnectionType",
-    "ConfigFactory",
-    "ConnectionKind",
-    "DBConnectionConfig",
+    "DBType",
+    "DBConfig",
     "ConnectionManager",
     "ArangoConnection",
     "Neo4jConnection",
+    "PostgresConnection",
     "TigerGraphConnection",
 ]
