@@ -42,11 +42,36 @@ from graflo.filter.onto import Clause
 from graflo.onto import AggregationType, DBFlavor
 from graflo.util.transform import pick_unique_dict
 
-from ..connection.onto import ArangoConnectionConfig
+from ..connection.onto import ArangoConfig
 
 logger = logging.getLogger(__name__)
 
 
+def _json_serializer(obj):
+    """JSON serializer for objects not serializable by default json code.
+
+    Handles datetime, date, time, and other non-serializable types.
+    Decimal should already be converted to float at the data source level.
+
+    Args:
+        obj: Object to serialize
+
+    Returns:
+        JSON-serializable representation
+    """
+    from datetime import date, datetime, time
+
+    if isinstance(obj, (datetime, date, time)):
+        return obj.isoformat()
+    # Decimal should be converted to float at source (SQLDataSource)
+    # But handle it here as a fallback
+    from decimal import Decimal
+
+    if isinstance(obj, Decimal):
+        return float(obj)
+    raise TypeError(f"Type {type(obj)} not serializable")
+
+
 class ArangoConnection(Connection):
     """ArangoDB-specific implementation of the Connection interface.
 
@@ -58,7 +83,7 @@ class ArangoConnection(Connection):
         conn: ArangoDB database connection instance
     """
 
-    def __init__(self, config: ArangoConnectionConfig):
+    def __init__(self, config: ArangoConfig):
         """Initialize ArangoDB connection.
 
         Args:
@@ -66,31 +91,100 @@ class ArangoConnection(Connection):
                 and database name
         """
         super().__init__()
-        client = ArangoClient(hosts=config.url, request_timeout=config.request_timeout)
+        # Store config for later use
+        self.config = config
+        # Validate required config values
+        if config.url is None:
+            raise ValueError("ArangoDB connection requires a URL to be configured")
+        if config.database is None:
+            raise ValueError(
+                "ArangoDB connection requires a database name to be configured"
+            )
 
-        self.conn = client.db(
-            config.database,
-            username=config.username,
-            password=config.password,
+        # ArangoDB accepts empty string for password if None
+        password = config.password if config.password is not None else ""
+        # ArangoDB has default username "root" if None
+        username = config.username if config.username is not None else "root"
+
+        # Store client for system operations
+        self.client = ArangoClient(
+            hosts=config.url, request_timeout=config.request_timeout
         )
+        # Connect to the configured database for regular operations
+        self.conn = self.client.db(
+            config.database,
+            username=username,
+            password=password,
+        )
+        # Store credentials for system operations
+        self._username = username
+        self._password = password
 
     def create_database(self, name: str):
         """Create a new ArangoDB database.
 
+        Database creation/deletion operations must be performed from the _system database.
+
         Args:
             name: Name of the database to create
         """
-        if not self.conn.has_database(name):
-            self.conn.create_database(name)
+        try:
+            # Connect to _system database for system operations
+            system_db = self.client.db(
+                "_system", username=self._username, password=self._password
+            )
+            if not system_db.has_database(name):
+                try:
+                    system_db.create_database(name)
+                    logger.info(f"Successfully created ArangoDB database '{name}'")
+                except Exception as create_error:
+                    logger.error(
+                        f"Failed to create ArangoDB database '{name}': {create_error}",
+                        exc_info=True,
+                    )
+                    raise
+            else:
+                logger.debug(f"ArangoDB database '{name}' already exists")
+        except Exception as e:
+            logger.error(
+                f"Error creating ArangoDB database '{name}': {e}",
+                exc_info=True,
+            )
+            raise
 
     def delete_database(self, name: str):
         """Delete an ArangoDB database.
 
+        Database creation/deletion operations must be performed from the _system database.
+
         Args:
             name: Name of the database to delete
         """
-        if not self.conn.has_database(name):
-            self.conn.delete_database(name)
+        try:
+            # Connect to _system database for system operations
+            system_db = self.client.db(
+                "_system", username=self._username, password=self._password
+            )
+            if system_db.has_database(name):
+                try:
+                    system_db.delete_database(name)
+                    logger.info(f"Successfully deleted ArangoDB database '{name}'")
+                except Exception as delete_error:
+                    logger.error(
+                        f"Failed to delete ArangoDB database '{name}': {delete_error}",
+                        exc_info=True,
+                    )
+                    raise
+            else:
+                logger.debug(
+                    f"ArangoDB database '{name}' does not exist, skipping deletion"
+                )
+        except Exception as e:
+            logger.error(
+                f"Error deleting ArangoDB database '{name}': {e}",
+                exc_info=True,
+            )
+            raise
 
     def execute(self, query, **kwargs):
         """Execute an AQL query.
@@ -113,14 +207,100 @@ class ArangoConnection(Connection):
     def init_db(self, schema: Schema, clean_start):
         """Initialize ArangoDB with the given schema.
 
+        Checks if the database exists and creates it if it doesn't.
+        Uses schema.general.name if database is not set in config.
+
         Args:
             schema: Schema containing graph structure definitions
             clean_start: If True, delete all existing collections before initialization
         """
-        if clean_start:
-            self.delete_graph_structure([], [], delete_all=True)
-        self.define_schema(schema)
-        self.define_indexes(schema)
+        # Determine database name: use config.database if set, otherwise use schema.general.name
+        db_name = self.config.database
+        if not db_name:
+            db_name = schema.general.name
+            # Update config for subsequent operations
+            self.config.database = db_name
+
+        # Check if database exists and create it if it doesn't
+        # Use context manager pattern for system database operations
+        try:
+            system_db = self.client.db(
+                "_system", username=self._username, password=self._password
+            )
+            if not system_db.has_database(db_name):
+                logger.info(f"Database '{db_name}' does not exist, creating it...")
+                try:
+                    system_db.create_database(db_name)
+                    logger.info(f"Successfully created database '{db_name}'")
+                except Exception as create_error:
+                    logger.error(
+                        f"Failed to create database '{db_name}': {create_error}",
+                        exc_info=True,
+                    )
+                    raise
+
+            # Reconnect to the target database (newly created or existing)
+            if (
+                self.config.database != db_name
+                or not hasattr(self, "_db_connected")
+                or self._db_connected != db_name
+            ):
+                try:
+                    self.conn = self.client.db(
+                        db_name, username=self._username, password=self._password
+                    )
+                    self._db_connected = db_name
+                    logger.debug(f"Connected to database '{db_name}'")
+                except Exception as conn_error:
+                    logger.error(
+                        f"Failed to connect to database '{db_name}': {conn_error}",
+                        exc_info=True,
+                    )
+                    raise
+        except Exception as e:
+            logger.error(
+                f"Error during database initialization for '{db_name}': {e}",
+                exc_info=True,
+            )
+            raise
+
+        try:
+            if clean_start:
+                try:
+                    self.delete_graph_structure([], [], delete_all=True)
+                    logger.debug(f"Cleaned database '{db_name}' for fresh start")
+                except Exception as clean_error:
+                    logger.warning(
+                        f"Error during clean_start for database '{db_name}': {clean_error}",
+                        exc_info=True,
+                    )
+                    # Continue - may be first run or already clean
+
+            try:
+                self.define_schema(schema)
+                logger.debug(f"Defined schema for database '{db_name}'")
+            except Exception as schema_error:
+                logger.error(
+                    f"Failed to define schema for database '{db_name}': {schema_error}",
+                    exc_info=True,
+                )
+                raise
+
+            try:
+                self.define_indexes(schema)
+                logger.debug(f"Defined indexes for database '{db_name}'")
+            except Exception as index_error:
+                logger.error(
+                    f"Failed to define indexes for database '{db_name}': {index_error}",
+                    exc_info=True,
+                )
+                raise
+        except Exception as e:
+            logger.error(
+                f"Error during database schema initialization for '{db_name}': {e}",
+                exc_info=True,
+            )
+            raise
 
     def define_schema(self, schema: Schema):
         """Define ArangoDB collections based on schema.
@@ -147,6 +327,11 @@ class ArangoConnection(Connection):
         for item in schema.edge_config.edges_list():
             u, v = item.source, item.target
             gname = item.graph_name
+            if not gname:
+                logger.warning(
+                    f"Edge {item.source} -> {item.target} has no graph_name, skipping"
+                )
+                continue
             logger.info(f"{item.source}, {item.target}, {gname}")
             if self.conn.has_graph(gname):
                 g = self.conn.graph(gname)
@@ -175,13 +360,20 @@ class ArangoConnection(Connection):
         """
         for item in edges:
             gname = item.graph_name
+            if not gname:
+                logger.warning("Edge has no graph_name, skipping")
+                continue
             if self.conn.has_graph(gname):
                 g = self.conn.graph(gname)
             else:
                 g = self.conn.create_graph(gname)  # type: ignore
-            if not g.has_edge_definition(item.collection_name):
+            collection_name = item.collection_name
+            if not collection_name:
+                logger.warning("Edge has no collection_name, skipping")
+                continue
+            if not g.has_edge_definition(collection_name):
                 _ = g.create_edge_definition(
-                    edge_collection=item.collection_name,
+                    edge_collection=collection_name,
                     from_vertex_collections=[item._source_collection],
                     to_vertex_collections=[item._target_collection],
                 )
@@ -240,7 +432,11 @@ class ArangoConnection(Connection):
             edges: List of edge configurations containing index definitions
         """
         for edge in edges:
-            general_collection = self.conn.collection(edge.collection_name)
+            collection_name = edge.collection_name
+            if not collection_name:
+                logger.warning("Edge has no collection_name, skipping index creation")
+                continue
+            general_collection = self.conn.collection(collection_name)
             for index_obj in edge.indexes:
                 self._add_index(general_collection, index_obj)
 
@@ -364,7 +560,7 @@ class ArangoConnection(Connection):
         if isinstance(docs, list):
             if filter_uniques:
                 docs = pick_unique_dict(docs)
-            docs = json.dumps(docs)
+            docs = json.dumps(docs, default=_json_serializer)
         if match_keys is None:
             upsert_clause = ""
             update_clause = ""
@@ -680,7 +876,7 @@ class ArangoConnection(Connection):
 
         if to_type:
             filter_parts.append(f"e._to LIKE '{to_type}/%'")
-        if to_id:
+        if to_id and to_type:
             if not to_id.startswith(to_type):
                 to_vertex_id = f"{to_type}/{to_id}"
             else:
