@@ -24,10 +24,11 @@ Example:
 import contextlib
 import json
 import logging
-from typing import Any
+from typing import Any, cast
 
 
 import requests
+from requests import exceptions as requests_exceptions
 
 from pyTigerGraph import TigerGraphConnection as PyTigerGraphConnection
 
@@ -36,10 +37,11 @@ from graflo.architecture.onto import Index
 from graflo.architecture.schema import Schema
 from graflo.architecture.vertex import FieldType, Vertex, VertexConfig
 from graflo.db.conn import Connection
-from graflo.db.connection.onto import TigergraphConnectionConfig
+from graflo.db.connection.onto import TigergraphConfig
 from graflo.filter.onto import Clause, Expression
 from graflo.onto import AggregationType, DBFlavor, ExpressionFlavor
 from graflo.util.transform import pick_unique_dict
+from urllib.parse import quote
 
 logger = logging.getLogger(__name__)
 
@@ -58,7 +60,7 @@ class TigerGraphConnection(Connection):
 
     flavor = DBFlavor.TIGERGRAPH
 
-    def __init__(self, config: TigergraphConnectionConfig):
+    def __init__(self, config: TigergraphConfig):
         super().__init__()
         self.config = config
         # Store base URLs for REST++ and GSQL endpoints
@@ -66,18 +68,33 @@ class TigerGraphConnection(Connection):
         self.gsql_url = f"{config.url_without_port}:{config.gs_port}"
 
         # Initialize pyTigerGraph connection for most operations
-        self.conn = PyTigerGraphConnection(
-            host=config.url_without_port,
-            restppPort=config.port,
-            gsPort=config.gs_port,
-            graphname=config.database,
-            username=config.username,
-            password=config.password,
-            certPath=getattr(config, "certPath", None),
+        # Use type narrowing to help type checker understand non-None values
+        # PyTigerGraphConnection has defaults for all parameters, so None values are acceptable
+        restpp_port: int | str = config.port if config.port is not None else "9000"
+        gs_port: int | str = config.gs_port if config.gs_port is not None else "14240"
+        graphname: str = (
+            config.database if config.database is not None else "DefaultGraph"
         )
+        username: str = config.username if config.username is not None else "tigergraph"
+        password: str = config.password if config.password is not None else "tigergraph"
+        cert_path: str | None = getattr(config, "certPath", None)
+
+        # Build connection kwargs, only include certPath if it's not None
+        conn_kwargs: dict[str, Any] = {
+            "host": config.url_without_port,
+            "restppPort": restpp_port,
+            "gsPort": gs_port,
+            "graphname": graphname,
+            "username": username,
+            "password": password,
+        }
+        if cert_path is not None:
+            conn_kwargs["certPath"] = cert_path
+
+        self.conn = PyTigerGraphConnection(**conn_kwargs)
 
         # Get authentication token if secret is provided
-        if hasattr(config, "secret") and config.secret:
+        if config.secret:
             try:
                 self.conn.getToken(config.secret)
             except Exception as e:
@@ -148,7 +165,7 @@ class TigerGraphConnection(Connection):
             response.raise_for_status()
             return response.json()
 
-        except requests.exceptions.HTTPError as errh:
+        except requests_exceptions.HTTPError as errh:
             logger.error(f"HTTP Error: {errh}")
             error_response = {"error": True, "message": str(errh)}
             try:
@@ -161,13 +178,13 @@ class TigerGraphConnection(Connection):
             except Exception:
                 error_response["details"] = response.text
             return error_response
-        except requests.exceptions.ConnectionError as errc:
+        except requests_exceptions.ConnectionError as errc:
             logger.error(f"Error Connecting: {errc}")
             return {"error": True, "message": str(errc)}
-        except requests.exceptions.Timeout as errt:
+        except requests_exceptions.Timeout as errt:
             logger.error(f"Timeout Error: {errt}")
             return {"error": True, "message": str(errt)}
-        except requests.exceptions.RequestException as err:
+        except requests_exceptions.RequestException as err:
             logger.error(f"An unexpected error occurred: {err}")
             return {"error": True, "message": str(err)}
 
@@ -442,43 +459,96 @@ class TigerGraphConnection(Connection):
         # Use schema.general.name for graph creation
         graph_created = False
 
-        # Ensure config.database is set to the graph name
-        # This ensures subsequent operations use the correct graph
+        # Determine graph name: use config.database if set, otherwise use schema.general.name
         graph_name = self.config.database
+        if not graph_name:
+            graph_name = schema.general.name
+            # Update config for subsequent operations
+            self.config.database = graph_name
+            logger.info(f"Using schema name '{graph_name}' from schema.general.name")
 
         try:
             if clean_start:
-                # Delete all graphs, edges, and vertices (full teardown)
-                self.delete_graph_structure([], [], delete_all=True)
+                try:
+                    # Delete all graphs, edges, and vertices (full teardown)
+                    self.delete_graph_structure([], [], delete_all=True)
+                    logger.debug(f"Cleaned graph '{graph_name}' for fresh start")
+                except Exception as clean_error:
+                    logger.warning(
+                        f"Error during clean_start for graph '{graph_name}': {clean_error}",
+                        exc_info=True,
+                    )
+                    # Continue - may be first run or already clean
 
             # Step 1: Create vertex and edge types globally first
             # These must exist before they can be included in CREATE GRAPH
             logger.debug(
                 f"Creating vertex and edge types globally for graph '{graph_name}'"
             )
-            vertex_names = self._create_vertex_types_global(schema.vertex_config)
-            edge_names = self._create_edge_types_global(
-                schema.edge_config.edges_list(include_aux=True)
-            )
-
-            # Step 2: Create graph with vertices and edges explicitly attached
-            if not self.graph_exists(graph_name):
-                logger.debug(f"Creating graph '{graph_name}' with types in init_db")
-                self.create_database(
-                    graph_name, vertex_names=vertex_names, edge_names=edge_names
-                )
-                graph_created = True
-            else:
-                logger.debug(f"Graph '{graph_name}' already exists in init_db")
-                # If graph already exists, associate types via ALTER GRAPH
-                self.define_vertex_collections(schema.vertex_config)
-                self.define_edge_collections(
+            try:
+                vertex_names = self._create_vertex_types_global(schema.vertex_config)
+                edge_names = self._create_edge_types_global(
                     schema.edge_config.edges_list(include_aux=True)
                 )
+                logger.debug(
+                    f"Created {len(vertex_names)} vertex types and {len(edge_names)} edge types"
+                )
+            except Exception as type_error:
+                logger.error(
+                    f"Failed to create vertex/edge types for graph '{graph_name}': {type_error}",
+                    exc_info=True,
+                )
+                raise
+
+            # Step 2: Create graph with vertices and edges explicitly attached
+            try:
+                if not self.graph_exists(graph_name):
+                    logger.debug(f"Creating graph '{graph_name}' with types in init_db")
+                    try:
+                        self.create_database(
+                            graph_name,
+                            vertex_names=vertex_names,
+                            edge_names=edge_names,
+                        )
+                        graph_created = True
+                        logger.info(f"Successfully created graph '{graph_name}'")
+                    except Exception as create_error:
+                        logger.error(
+                            f"Failed to create graph '{graph_name}': {create_error}",
+                            exc_info=True,
+                        )
+                        raise
+                else:
+                    logger.debug(f"Graph '{graph_name}' already exists in init_db")
+                    # If graph already exists, associate types via ALTER GRAPH
+                    try:
+                        self.define_vertex_collections(schema.vertex_config)
+                        self.define_edge_collections(
+                            schema.edge_config.edges_list(include_aux=True)
+                        )
+                    except Exception as define_error:
+                        logger.warning(
+                            f"Could not define collections for existing graph '{graph_name}': {define_error}",
+                            exc_info=True,
+                        )
+                        # Continue - graph exists, collections may already be defined
+            except Exception as graph_error:
+                logger.error(
+                    f"Error during graph creation/verification for '{graph_name}': {graph_error}",
+                    exc_info=True,
+                )
+                raise
 
             # Step 3: Define indexes
-            self.define_indexes(schema)
-            logger.info("Index definition completed")
+            try:
+                self.define_indexes(schema)
+                logger.info(f"Index definition completed for graph '{graph_name}'")
+            except Exception as index_error:
+                logger.error(
+                    f"Failed to define indexes for graph '{graph_name}': {index_error}",
+                    exc_info=True,
+                )
+                raise
         except Exception as e:
             logger.error(f"Error initializing database: {e}")
             # Graceful teardown: if graph was created in this session, clean it up
@@ -528,8 +598,7 @@ class TigerGraphConnection(Connection):
         Returns:
             str: Formatted field definitions for GSQL CREATE VERTEX statement
         """
-        # Get fields with TigerGraph default types applied (None -> STRING)
-        fields = vertex.get_fields_with_defaults(DBFlavor.TIGERGRAPH, with_aux=False)
+        fields = vertex.fields
 
         if not fields:
             # Default fields if none specified
@@ -1325,7 +1394,7 @@ class TigerGraphConnection(Connection):
             # TigerGraph response is a JSON object
             return response.json()
 
-        except requests.exceptions.HTTPError as errh:
+        except requests_exceptions.HTTPError as errh:
             logger.error(f"HTTP Error: {errh}")
             error_details = ""
             try:
@@ -1333,13 +1402,13 @@ class TigerGraphConnection(Connection):
             except Exception:
                 pass
             return {"error": True, "message": str(errh), "details": error_details}
-        except requests.exceptions.ConnectionError as errc:
+        except requests_exceptions.ConnectionError as errc:
             logger.error(f"Error Connecting: {errc}")
             return {"error": True, "message": str(errc)}
-        except requests.exceptions.Timeout as errt:
+        except requests_exceptions.Timeout as errt:
             logger.error(f"Timeout Error: {errt}")
             return {"error": True, "message": str(errt)}
-        except requests.exceptions.RequestException as err:
+        except requests_exceptions.RequestException as err:
             logger.error(f"An unexpected error occurred: {err}")
             return {"error": True, "message": str(err)}
 
@@ -1370,6 +1439,8 @@ class TigerGraphConnection(Connection):
             # Build REST++ endpoint URL
             host = f"{self.config.url_without_port}:{self.config.port}"
             graph_name = self.config.database
+            if not graph_name:
+                raise ValueError("Graph name (database) must be configured")
 
             # Send the upsert request with username/password authentication
             result = self._upsert_data(
@@ -1612,6 +1683,8 @@ class TigerGraphConnection(Connection):
             # Build REST++ endpoint URL
             host = f"{self.config.url_without_port}:{self.config.port}"
             graph_name = self.config.database
+            if not graph_name:
+                raise ValueError("Graph name (database) must be configured")
 
             # Send the upsert request with username/password authentication
             result = self._upsert_data(
@@ -1708,40 +1781,6 @@ class TigerGraphConnection(Connection):
         else:
             return ""
 
-    def _get_field_types_for_vertex(
-        self, vertex_name: str, vertex_config: None | VertexConfig = None
-    ) -> dict[str, FieldType] | None:
-        """Get field types for a vertex from vertex config.
-
-        Args:
-            vertex_name: Name of the vertex type (or dbname)
-            vertex_config: Vertex configuration to use for lookup
-
-        Returns:
-            dict[str, FieldType]: Mapping of field names to their FieldType enum values, or None if not available
-        """
-        if vertex_config is None:
-            return None
-
-        try:
-            # Get fields with TigerGraph defaults applied
-            fields = vertex_config.fields(
-                vertex_name,
-                with_aux=False,
-                as_names=False,
-                db_flavor=DBFlavor.TIGERGRAPH,
-            )
-            # Build field_types dict: {field_name: FieldType}
-            field_types = {}
-            for field in fields:
-                if field.type:
-                    # Convert string type to FieldType enum
-                    field_types[field.name] = FieldType(field.type)
-            return field_types if field_types else None
-        except (KeyError, ValueError):
-            # Vertex not found in config
-            return None
-
     def fetch_docs(
         self,
         class_name,
@@ -1776,11 +1815,10 @@ class TigerGraphConnection(Connection):
 
             # Get field_types from kwargs or auto-detect from vertex_config
             field_types = kwargs.get("field_types")
-            if field_types is None:
-                vertex_config = kwargs.get("vertex_config")
-                field_types = self._get_field_types_for_vertex(
-                    class_name, vertex_config
-                )
+            vertex_config = kwargs.get("vertex_config")
+
+            if field_types is None and vertex_config is not None:
+                field_types = {f.name: f.type for f in vertex_config.fields(class_name)}
 
             # Build REST++ filter string with field type information
             filter_str = self._render_rest_filter(filters, field_types=field_types)
@@ -1788,7 +1826,6 @@ class TigerGraphConnection(Connection):
             # Build REST++ API endpoint with query parameters manually
             # Format: /graph/{graph_name}/vertices/{vertex_type}?filter=...&limit=...
             # Example: /graph/g22c97325/vertices/Author?filter=hindex>20&limit=10
-            from urllib.parse import quote
 
             endpoint = f"/graph/{graph_name}/vertices/{class_name}"
             query_parts = []
@@ -1809,7 +1846,9 @@ class TigerGraphConnection(Connection):
             response = self._call_restpp_api(endpoint)
 
             # Parse REST++ response (vertices only)
-            result = self._parse_restpp_response(response, is_edge=False)
+            result: list[dict[str, Any]] = self._parse_restpp_response(
+                response, is_edge=False
+            )
 
             # Check for errors
             if isinstance(response, dict) and response.get("error"):
@@ -1820,12 +1859,15 @@ class TigerGraphConnection(Connection):
             # Apply projection (client-side projection is acceptable for result formatting)
             if return_keys is not None:
                 result = [
-                    {k: doc.get(k) for k in return_keys if k in doc} for doc in result
+                    {k: doc.get(k) for k in return_keys if k in doc}
+                    for doc in result
+                    if isinstance(doc, dict)
                 ]
             elif unset_keys is not None:
                 result = [
                     {k: v for k, v in doc.items() if k not in unset_keys}
                     for doc in result
+                    if isinstance(doc, dict)
                 ]
 
             return result
@@ -1881,12 +1923,25 @@ class TigerGraphConnection(Connection):
                 f"Fetching edges using pyTigerGraph: from_type={from_type}, from_id={from_id}, edge_type={edge_type}"
             )
 
-            edges = self.conn.getEdges(from_type, from_id, edge_type)
+            # Handle None edge_type by passing empty string (default behavior)
+            edge_type_str = edge_type if edge_type is not None else ""
+            edges = self.conn.getEdges(from_type, from_id, edge_type_str, fmt="py")
 
             # Parse pyTigerGraph response format
             # getEdges returns list of dicts with format like:
             # [{"e_type": "...", "from": {...}, "to": {...}, "attributes": {...}}, ...]
-            result = edges
+            # Type annotation: result is list[dict[str, Any]]
+            # getEdges can return dict, str, or DataFrame, but with fmt="py" it returns dict
+            if isinstance(edges, list):
+                # Type narrowing: after isinstance check, we know it's a list
+                # Use cast to help type checker understand the elements are dicts
+                result = cast(list[dict[str, Any]], edges)
+            elif isinstance(edges, dict):
+                # If it's a single dict, wrap it in a list
+                result = [cast(dict[str, Any], edges)]
+            else:
+                # Fallback for unexpected types
+                result: list[dict[str, Any]] = []
 
             # Apply limit if specified (client-side since pyTigerGraph doesn't support it)
             if limit is not None and limit > 0:
@@ -1895,12 +1950,15 @@ class TigerGraphConnection(Connection):
             # Apply projection (client-side projection is acceptable for result formatting)
             if return_keys is not None:
                 result = [
-                    {k: doc.get(k) for k in return_keys if k in doc} for doc in result
+                    {k: doc.get(k) for k in return_keys if k in doc}
+                    for doc in result
+                    if isinstance(doc, dict)
                 ]
             elif unset_keys is not None:
                 result = [
                     {k: v for k, v in doc.items() if k not in unset_keys}
                     for doc in result
+                    if isinstance(doc, dict)
                 ]
 
             return result
