@@ -293,7 +293,7 @@ class SchemaPlotter:
         kwargs = {"vfield": True, "vertex_sh": vertex_prefix_dict}
         for k in vconf.vertex_set:
             index_fields = vconf.index(k)
-            fields = vconf.fields(k)
+            fields = vconf.fields_names(k)
             kwargs["vertex"] = k
             nodes_collection = [
                 (
