@@ -55,12 +55,14 @@ class ChunkerType(BaseEnum):
     JSON: For JSON files
     JSONL: For JSON Lines files
     TABLE: For CSV/TSV files
+    PARQUET: For Parquet files (columnar storage format)
     TRIVIAL: For in-memory lists
     """
 
     JSON = "json"
     JSONL = "jsonl"
     TABLE = "table"
+    PARQUET = "parquet"
     TRIVIAL = "trivial"
 
 
@@ -183,7 +185,11 @@ class FileChunker(AbstractChunker):
 
         Raises:
             StopIteration: When end of file is reached
+            RuntimeError: If file is not opened (should not happen in normal flow)
         """
+        # file_obj is guaranteed to be open after _prepare_iteration() is called
+        if self.file_obj is None:
+            raise RuntimeError("File should be opened before calling _next_item()")
         return next(self.file_obj)
 
     def _prepare_iteration(self):
@@ -213,11 +219,13 @@ class FileChunker(AbstractChunker):
 
         Raises:
             StopIteration: When end of file is reached or limit is reached
+            RuntimeError: If file is not opened (should not happen in normal flow)
         """
         batch = []
 
         if self._limit_reached():
-            self.file_obj.close()
+            if self.file_obj is not None:
+                self.file_obj.close()
             raise StopIteration
         while len(batch) < self.batch_size and not self._limit_reached():
             try:
@@ -226,7 +234,8 @@ class FileChunker(AbstractChunker):
             except StopIteration:
                 if batch:
                     return batch
-                self.file_obj.close()
+                if self.file_obj is not None:
+                    self.file_obj.close()
                 raise StopIteration
 
         return batch
@@ -251,6 +260,9 @@ class TableChunker(FileChunker):
     def _prepare_iteration(self):
         """Read the header row and prepare for iteration."""
         super()._prepare_iteration()
+        # After super()._prepare_iteration(), file_obj is guaranteed to be open
+        if self.file_obj is None:
+            raise RuntimeError("File should be opened by parent _prepare_iteration()")
         header = next(self.file_obj)
         self.header = header.rstrip("\n").split(self.sep)
 
@@ -303,6 +315,9 @@ class JsonChunker(FileChunker):
     def _prepare_iteration(self):
         """Initialize the JSON parser for streaming."""
         super()._prepare_iteration()
+        # After super()._prepare_iteration(), file_obj is guaranteed to be open
+        if self.file_obj is None:
+            raise RuntimeError("File should be opened by parent _prepare_iteration()")
         self.parser = ijson.items(self.file_obj, "item")
 
     def _next_item(self):
@@ -356,6 +371,56 @@ class TrivialChunker(AbstractChunker):
         return batch
 
 
+class ParquetChunker(FileChunker):
+    """Chunker for Parquet files.
+
+    This class extends FileChunker to handle Parquet files (columnar storage format).
+    It reads Parquet files in batches using pandas, converting each batch to dictionaries.
+
+    Args:
+        filename: Path to the Parquet file
+        **kwargs: Additional arguments for FileChunker
+    """
+
+    def __init__(self, filename: Path, **kwargs):
+        super().__init__(filename=filename, **kwargs)
+        self.df: pd.DataFrame | None = None
+        self.columns: list[str] | None = None
+
+    def _prepare_iteration(self):
+        """Prepare for iteration by loading the Parquet file."""
+        super()._prepare_iteration()
+        try:
+            self.df = pd.read_parquet(self.filename)
+            self.columns = self.df.columns.tolist()
+        except ImportError:
+            raise ImportError(
+                "Reading Parquet files requires 'pyarrow' or 'fastparquet'. "
+                "Install with: pip install pyarrow"
+            )
+        except Exception as e:
+            logger.error(f"Failed to read Parquet file '{self.filename}': {e}")
+            raise
+
+    def _next_item(self):
+        """Get the next batch of rows as dictionaries.
+
+        Returns:
+            list[dict]: Next batch of rows as dictionaries
+        """
+        if self.df is None or self.columns is None:
+            return []
+
+        cid = self.cnt
+        end_idx = min(cid + self.batch_size, len(self.df))
+        if cid >= end_idx:
+            return []
+
+        pre_batch = self.df.iloc[cid:end_idx].values.tolist()
+        batch = [{k: v for k, v in zip(self.columns, item)} for item in pre_batch]
+        return batch
+
+
 class ChunkerDataFrame(AbstractChunker):
     """Chunker for Pandas DataFrames.
 
@@ -427,6 +492,8 @@ class ChunkerFactory:
             return ChunkerType.JSONL
         elif base_suffix in (".csv", ".tsv", ".txt"):
             return ChunkerType.TABLE
+        elif base_suffix == ".parquet":
+            return ChunkerType.PARQUET
         else:
             raise ValueError(
                 f"Could not guess chunker type for file extension: {base_suffix}"
@@ -459,13 +526,14 @@ class ChunkerFactory:
         elif isinstance(resource, Path):
             if chunker_type is None:
                 chunker_type = cls._guess_chunker_type(resource)
-
             if chunker_type == ChunkerType.JSON:
                 return JsonChunker(filename=resource, **kwargs)
             elif chunker_type == ChunkerType.JSONL:
                 return JsonlChunker(filename=resource, **kwargs)
             elif chunker_type == ChunkerType.TABLE:
                 return TableChunker(filename=resource, **kwargs)
+            elif chunker_type == ChunkerType.PARQUET:
+                return ParquetChunker(filename=resource, **kwargs)
             else:
                 raise ValueError(f"Unknown chunker type: {chunker_type}")
         else:
